@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "json"
 
 module SimpleCov
@@ -9,7 +11,11 @@ module SimpleCov
 
       def read
         return nil unless File.exist?(last_run_path)
-        JSON.parse(File.read(last_run_path))
+
+        json = File.read(last_run_path)
+        return nil if json.strip.empty?
+
+        JSON.parse(json, symbolize_names: true)
       end
 
       def write(json)
