@@ -5,7 +5,7 @@ require "forwardable"
 
 module SimpleCov
   #
-  # A simplecov code coverage result, initialized from the Hash Ruby 1.9's built-in coverage
+  # A simplecov code coverage result, initialized from the Hash Ruby's built-in coverage
   # library generates (Coverage.result).
   #
   class Result
@@ -20,15 +20,18 @@ module SimpleCov
     # Explicitly set the command name that was used for this coverage result. Defaults to SimpleCov.command_name
     attr_writer :command_name
 
-    def_delegators :files, :covered_percent, :covered_percentages, :least_covered_file, :covered_strength, :covered_lines, :missed_lines
+    def_delegators :files, :covered_percent, :covered_percentages, :least_covered_file, :covered_strength, :covered_lines, :missed_lines, :total_branches, :covered_branches, :missed_branches, :coverage_statistics
     def_delegator :files, :lines_of_code, :total_lines
 
     # Initialize a new SimpleCov::Result from given Coverage.result (a Hash of filenames each containing an array of
     # coverage data)
-    def initialize(original_result)
-      @original_result = original_result.freeze
-      @files = SimpleCov::FileList.new(original_result.map do |filename, coverage|
-        SimpleCov::SourceFile.new(filename, coverage) if File.file?(filename)
+    def initialize(original_result, command_name: nil, created_at: nil)
+      result = adapt_result(original_result)
+      @original_result = result.freeze
+      @command_name = command_name
+      @created_at = created_at
+      @files = SimpleCov::FileList.new(result.map do |filename, coverage|
+        SimpleCov::SourceFile.new(filename, JSON.parse(JSON.dump(coverage))) if File.file?(filename)
       end.compact.sort_by(&:filename))
       filter!
     end
@@ -61,20 +64,52 @@ module SimpleCov
 
     # Returns a hash representation of this Result that can be used for marshalling it into JSON
     def to_hash
-      {command_name => {"coverage" => coverage, "timestamp" => created_at.to_i}}
+      {
+        command_name => {
+          "coverage" => coverage,
+          "timestamp" => created_at.to_i
+        }
+      }
+    end
+
+    def time_since_creation
+      Time.now - created_at
     end
 
     # Loads a SimpleCov::Result#to_hash dump
     def self.from_hash(hash)
-      command_name, data = hash.first
-      result = SimpleCov::Result.new(data["coverage"])
-      result.command_name = command_name
-      result.created_at = Time.at(data["timestamp"])
-      result
+      hash.map do |command_name, data|
+        new(data.fetch("coverage"), command_name: command_name, created_at: Time.at(data["timestamp"]))
+      end
     end
 
   private
 
+    # We changed the format of the raw result data in simplecov, as people are likely
+    # to have "old" resultsets lying around (but not too old so that they're still
+    # considered we can adapt them).
+    # See https://github.com/simplecov-ruby/simplecov/pull/824#issuecomment-576049747
+    def adapt_result(result)
+      if pre_simplecov_0_18_result?(result)
+        adapt_pre_simplecov_0_18_result(result)
+      else
+        result
+      end
+    end
+
+    # pre 0.18 coverage data pointed from file directly to an array of line coverage
+    def pre_simplecov_0_18_result?(result)
+      _key, data = result.first
+
+      data.is_a?(Array)
+    end
+
+    def adapt_pre_simplecov_0_18_result(result)
+      result.transform_values do |line_coverage_data|
+        {"lines" => line_coverage_data}
+      end
+    end
+
     def coverage
       keys = original_result.keys & filenames
       Hash[keys.zip(original_result.values_at(*keys))]
